==> crm-commom-vo-1.1.9.25.release.jar: com/biz/crm/nebular/dms/repfeepool/RepFeePoolItemVo.java <==
package com.biz.crm.nebular.dms.repfeepool;

import com.biz.crm.nebular.mdm.CrmExtVo;
import com.biz.crm.nebular.mdm.CrmFileVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.math.BigDecimal;
import java.util.List;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 货补费用池明细VO（产品维度）
 * @Author: chenrong
 * @Date: 2020/11/24 17:11
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@ApiModel(value = "货补费用池明细VO（产品维度）")
public class RepFeePoolItemVo extends CrmExtVo {

  /**
   * 货补费用池明细编码
   */
  @ApiModelProperty("货补费用池明细编码")
  private String code;
  /**
   * 货补费用池
   */
  @ApiModelProperty("货补费用池")
  private RepFeePoolVo repFeePoolVo;
  /**
   * 货补费用池编码
   */
  @ApiModelProperty("货补费用池编码")
  private String repFeePoolCode;
  /**
   * 支付类型
   */
  @ApiModelProperty("支付类型")
  private Integer payType;
  /**
   * 商品编码
   */
  @ApiModelProperty("商品编码")
  private String productCode;
  /**
   * 商品名称
   */
  @ApiModelProperty("商品名称")
  private String productName;
  /**
   * 组合商品数量
   */
  @ApiModelProperty("组合商品数量")
  private Integer productSize = 1;
  /**
   * 成本价格
   */
  @ApiModelProperty("成本价格")
  private BigDecimal costPrice = BigDecimal.ZERO;
  /**
   * 销售价格
   */
  @ApiModelProperty("销售价格")
  private BigDecimal salePrice = BigDecimal.ZERO;
  /**
   * 商品单位
   */
  @ApiModelProperty("商品单位")
  private String unit;
  /**
   * 商品单位名称
   */
  @ApiModelProperty("商品单位名称")
  private String unitName;
  /**
   * 产品规格
   */
  @ApiModelProperty("产品规格")
  private String spec;
  /**
   * 上账数量
   */
  @ApiModelProperty("上账数量")
  private BigDecimal onAccountCount = BigDecimal.ZERO;
  /**
   * 已使用数量
   */
  @ApiModelProperty("已使用数量")
  private BigDecimal usedCount = BigDecimal.ZERO;
  /**
   * 冻结数量
   */
  @ApiModelProperty("冻结数量")
  private BigDecimal frozenCount = BigDecimal.ZERO;
  /**
   * 可用数量
   */
  @ApiModelProperty("可用数量")
  private BigDecimal availableCount = BigDecimal.ZERO;
  /**
   * 上账金额
   */
  @ApiModelProperty("上账金额")
  private BigDecimal onAccountFee = BigDecimal.ZERO;
  /**
   * 已使用金额
   */
  @ApiModelProperty("已使用金额")
  private BigDecimal usedFee = BigDecimal.ZERO;
  /**
   * 冻结金额
   */
  @ApiModelProperty("冻结金额")
  private BigDecimal frozenFee = BigDecimal.ZERO;
  /**
   * 可用金额
   */
  @ApiModelProperty("可用金额")
  private BigDecimal availableFee = BigDecimal.ZERO;
  /**
   * 来源编码
   */
  @ApiModelProperty("来源编码")
  private String resourceCode;
  /**
   * 冗余字段，扣减数量
   */
  @ApiModelProperty("冗余字段，扣减数量")
  private BigDecimal subtractCount = BigDecimal.ZERO;
  /**
   * 冗余字段，冲销数量
   */
  @ApiModelProperty("冗余字段，冲销数量")
  private BigDecimal redTrickCount = BigDecimal.ZERO;

  /**
   * 冗余字段，文件对象集合
   */
  @ApiModelProperty(value = "冗余字段，文件对象集合")
  private List<RepFeePoolFileVo> files;
  /**
   * 冗余字段：产品列表
   */
  @ApiModelProperty(value = "冗余字段：产品列表")
  List<RepFeePoolItemProductVo> repFeePoolItemProductVos;

  /**
   * 货补费用池条目列表
   */
  @ApiModelProperty(value = "货补费用池条目列表")
  private List<RepFeePoolItemDetailVo> detailVos;

  /**
   * 数量调整类型
   */
  @ApiModelProperty(value = "数量调整类型")
  private Integer adjustCountType;

  /**
   * 金额调整类型
   */
  @ApiModelProperty(value = "金额调整类型")
  private Integer adjustFeeType;

  /**
   * 冗余字段：扣减顺序规则字典编码,默认时间正序
   */
  @ApiModelProperty(value = "扣减顺序规则字典编码")
  private String indexDictCode = "create_time";
  /**
   * 冗余字段：价格
   */
  @ApiModelProperty(value = "价格")
  private BigDecimal price = BigDecimal.ZERO;

  /**
   * 冗余字段：客户编码
   */
  @ApiModelProperty("冗余字段：客户编码")
  private String cusCode;

  /**
   * 冗余字段：客户名称
   */
  @ApiModelProperty("冗余字段：客户名称")
  private String cusName;

  /**
   * 冗余字段：客户所属组织编码
   */
  @ApiModelProperty("冗余字段：客户所属组织编码")
  private String cusOrgCode;

  /**
   * 冗余字段：客户所属组织名称
   */
  @ApiModelProperty("冗余字段：客户所属组织名称")
  private String cusOrgName;

  /**
   * 冗余字段：销售公司编码
   */
  @ApiModelProperty("冗余字段：销售公司编码")
  private String saleCompanyCode;

  /**
   * 冗余字段：销售公司名称
   */
  @ApiModelProperty("冗余字段：销售公司名称")
  private String saleCompanyName;

  /**
   * 冗余字段：客户所属渠道编码
   */
  @ApiModelProperty("冗余字段：客户所属渠道编码")
  private String cusChannelCode;

  /**
   * 冗余字段：客户所属渠道名称
   */
  @ApiModelProperty("冗余字段：客户所属渠道名称")
  private String cusChannelName;

  /**
   * 冗余字段：调整原因
   */
  @ApiModelProperty(value = "冗余字段：调整原因")
  private String adjustReason;
  /**
   * 冗余字段：调整数量
   */
  @ApiModelProperty(value = "冗余字段：调整数量")
  private BigDecimal adjustCount = BigDecimal.ZERO;
  /**
   * 冗余字段：调整金额
   */
  @ApiModelProperty(value = "冗余字段：调整金额")
  private BigDecimal adjustFee = BigDecimal.ZERO;

  /**
   * 冗余字段：是否使用前端传入到明细上的价格
   */
  @ApiModelProperty(value = "冗余字段：是否使用前端传入到明细上的价格")
  private boolean useItemPrice = true;

  /**
   * 冗余字段：货补费用池冻结明细编码
   */
  @ApiModelProperty(value = "冗余字段：货补费用池冻结明细编码")
  private String repFeePoolFrozenItemCode;
  /**
   * 上账原因
   */
  @ApiModelProperty(value = "上账原因")
  private String onAccountReason;
}

==> crm-commom-vo-1.1.9.41.release.jar: com/biz/crm/nebular/dms/repfeepool/RepFeePoolItemVo.java <==
package com.biz.crm.nebular.dms.repfeepool;

import com.biz.crm.nebular.mdm.CrmExtVo;
import com.biz.crm.nebular.mdm.CrmFileVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.math.BigDecimal;
import java.util.List;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * 货补费用池明细VO（产品维度）
 * @Author: chenrong
 * @Date: 2020/11/24 17:11
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@ApiModel(value = "货补费用池明细VO（产品维度）")
public class RepFeePoolItemVo extends CrmExtVo {

  /**
   * 货补费用池明细编码
   */
  @ApiModelProperty("货补费用池明细编码")
  private String code;
  /**
   * 货补费用池
   */
  @ApiModelProperty("货补费用池")
  private RepFeePoolVo repFeePoolVo;
  /**
   * 货补费用池编码
   */
  @ApiModelProperty("货补费用池编码")
  private String repFeePoolCode;
  /**
   * 支付类型
   */
  @ApiModelProperty("支付类型")
  private Integer payType;
  /**
   * 商品编码
   */
  @ApiModelProperty("商品编码")
  private String productCode;
  /**
   * 商品名称
   */
  @ApiModelProperty("商品名称")
  private String productName;
  /**
   * 组合商品数量
   */
  @ApiModelProperty("组合商品数量")
  private Integer productSize = 1;
  /**
   * 成本价格
   */
  @ApiModelProperty("成本价格")
  private BigDecimal costPrice = BigDecimal.ZERO;
  /**
   * 销售价格
   */
  @ApiModelProperty("销售价格")
  private BigDecimal salePrice = BigDecimal.ZERO;
  /**
   * 商品单位
   */
  @ApiModelProperty("商品单位")
  private String unit;
  /**
   * 商品单位名称
   */
  @ApiModelProperty("商品单位名称")
  private String unitName;
  /**
   * 产品规格
   */
  @ApiModelProperty("产品规格")
  private String spec;
  /**
   * 上账数量
   */
  @ApiModelProperty("上账数量")
  private BigDecimal onAccountCount = BigDecimal.ZERO;
  /**
   * 已使用数量
   */
  @ApiModelProperty("已使用数量")
  private BigDecimal usedCount = BigDecimal.ZERO;
  /**
   * 冻结数量
   */
  @ApiModelProperty("冻结数量")
  private BigDecimal frozenCount = BigDecimal.ZERO;
  /**
   * 可用数量
   */
  @ApiModelProperty("可用数量")
  private BigDecimal availableCount = BigDecimal.ZERO;
  /**
   * 上账金额
   */
  @ApiModelProperty("上账金额")
  private BigDecimal onAccountFee = BigDecimal.ZERO;
  /**
   * 已使用金额
   */
  @ApiModelProperty("已使用金额")
  private BigDecimal usedFee = BigDecimal.ZERO;
  /**
   * 冻结金额
   */
  @ApiModelProperty("冻结金额")
  private BigDecimal frozenFee = BigDecimal.ZERO;
  /**
   * 可用金额
   */
  @ApiModelProperty("可用金额")
  private BigDecimal availableFee = BigDecimal.ZERO;
  /**
   * 来源编码
   */
  @ApiModelProperty("来源编码")
  private String resourceCode;
  /**
   * 冗余字段，扣减数量
   */
  @ApiModelProperty("冗余字段，扣减数量")
  private BigDecimal subtractCount = BigDecimal.ZERO;
  /**
   * 冗余字段，冲销数量
   */
  @ApiModelProperty("冗余字段，冲销数量")
  private BigDecimal redTrickCount = BigDecimal.ZERO;

  /**
   * 冗余字段，文件对象集合
   */
  @ApiModelProperty(value = "冗余字段，文件对象集合")
  private List<RepFeePoolFileVo> files;
  /**
   * 冗余字段：产品列表
   */
  @ApiModelProperty(value = "冗余字段：产品列表")
  List<RepFeePoolItemProductVo> repFeePoolItemProductVos;

  /**
   * 货补费用池条目列表
   */
  @ApiModelProperty(value = "货补费用池条目列表")
  private List<RepFeePoolItemDetailVo> detailVos;

  /**
   * 数量调整类型
   */
  @ApiModelProperty(value = "数量调整类型")
  private Integer adjustCountType;

  /**
   * 金额调整类型
   */
  @ApiModelProperty(value = "金额调整类型")
  private Integer adjustFeeType;

  /**
   * 冗余字段：扣减顺序规则字典编码,默认时间正序
   */
  @ApiModelProperty(value = "扣减顺序规则字典编码")
  private String indexDictCode = "create_time";
  /**
   * 冗余字段：价格
   */
  @ApiModelProperty(value = "价格")
  private BigDecimal price = BigDecimal.ZERO;

  /**
   * 冗余字段：客户编码
   */
  @ApiModelProperty("冗余字段：客户编码")
  private String cusCode;

  /**
   * 冗余字段：客户名称
   */
  @ApiModelProperty("冗余字段：客户名称")
  private String cusName;

  /**
   * 冗余字段：客户所属组织编码
   */
  @ApiModelProperty("冗余字段：客户所属组织编码")
  private String cusOrgCode;

  /**
   * 冗余字段：客户所属组织名称
   */
  @ApiModelProperty("冗余字段：客户所属组织名称")
  private String cusOrgName;

  /**
   * 冗余字段：销售公司编码
   */
  @ApiModelProperty("冗余字段：销售公司编码")
  private String saleCompanyCode;

  /**
   * 冗余字段：销售公司名称
   */
  @ApiModelProperty("冗余字段：销售公司名称")
  private String saleCompanyName;

  /**
   * 冗余字段：客户所属渠道编码
   */
  @ApiModelProperty("冗余字段：客户所属渠道编码")
  private String cusChannelCode;

  /**
   * 冗余字段：客户所属渠道名称
   */
  @ApiModelProperty("冗余字段：客户所属渠道名称")
  private String cusChannelName;

  /**
   * 冗余字段：调整原因
   */
  @ApiModelProperty(value = "冗余字段：调整原因")
  private String adjustReason;
  /**
   * 冗余字段：调整数量
   */
  @ApiModelProperty(value = "冗余字段：调整数量")
  private BigDecimal adjustCount = BigDecimal.ZERO;
  /**
   * 冗余字段：调整金额
   */
  @ApiModelProperty(value = "冗余字段：调整金额")
  private BigDecimal adjustFee = BigDecimal.ZERO;

  /**
   * 冗余字段：是否使用前端传入到明细上的价格
   */
  @ApiModelProperty(value = "冗余字段：是否使用前端传入到明细上的价格")
  private boolean useItemPrice = false;

  /**
   * 冗余字段：货补费用池冻结明细编码
   */
  @ApiModelProperty(value = "冗余字段：货补费用池冻结明细编码")
  private String repFeePoolFrozenItemCode;
  /**
   * 上账原因
   */
  @ApiModelProperty(value = "上账原因")
  private String onAccountReason;
  /**
   * 冗余字段：是否审批过
   */
  private boolean isApproved = false;
  /**
   * 待提交数量(add)
   */
  private BigDecimal toSubmitNum = BigDecimal.ZERO;

  /**
   * 待提交金额(add)
   */
  private BigDecimal toSubmitFee = BigDecimal.ZERO;

  /**
   * 待审核数量(add)
   */
  private BigDecimal toExamineNum = BigDecimal.ZERO;

  /**
   * 待审核金额(add)
   */
  private BigDecimal toExamineFee = BigDecimal.ZERO;

  /**
   * 冗余字段：操作记录
   */
  private RepFeePoolBpmVo bpmVo;
}
